@@ -15,7 +15,8 @@ import sys
 
 IMG_CLASSES = ['f-m-img', 'group-pic', 'image-wrapper', 
 	'RichText', 'image-container', 'news_txt', "'article_con'", 
-	'photo_wrap', 'hideBeforeLoad', 'slide_container', 'rich_media_content']
+	'photo_wrap', 'hideBeforeLoad', 'slide_container', 'rich_media_content',
+	'is-widgets', 'entry-content']
 
 try:
 	with open('CREDENTIALS') as f:
@@ -31,6 +32,9 @@ def getCap(b, path):
 		b.find('p', id='first', class_='lead'))
 	if 'douban' in path:
 		wrapper = b.find('blockquote') or wrapper
+		title = b.find('td', class_='tablecc')
+		if title:
+			return title.text[3:]
 	if 'zhihu' in path:
 		answer = b.find('div', class_='RichContent-inner')
 		answer = answer and answer.text.strip()
@@ -130,4 +134,5 @@ def get(path, force_cache=False):
 		# don't know if this is the right thing to do, revisit if needed
 		result.cap = getCapForce(b, path)
 	result.video = getVideo(b)
+	result.url = path
 	return result
\ No newline at end of file
